Enum SubscriberState
enum SubscriberState {
Pending,
Active,
PendingUnsubscription,
}Variants
Pending
Subscription is pending.
We want to activate it as soon as possible, but we haven’t yet.
Active
Subscription is, to the best of our knowledge, active.
Messages will be received by us. Or at least we think so. There’s really no way to tell with the great rumqttc design.
PendingUnsubscription
Subscription is pending unsubscription.
We want to deactivate it as soon as possible, but we haven’t yet. We still receive messages and forward them to any remaining listeners.